# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.7]
### Added
- Default to confirmation states admin list.
- New django unified `JSONField` support.

## [0.1.6]
### Added
- Translation strings.

## [0.1.3]
### Added
- Admin search ui for confirmation state model.

## [0.1.1]
### Added
- `DEBUG_CODE_RESPONSE` setting. It adds generated 'code' field to a request confirmation response for easier debug.

## [0.1.0]
Initial version.
